@@ -64,7 +64,6 @@ const struct fieldinfo fieldinfos[]= {
   { FIELD("Multi-Arch"),       f_multiarch,       w_multiarch,      PKGIFPOFF(multiarch)     },
   { FIELD("Source"),           f_charfield,       w_charfield,      PKGIFPOFF(source)        },
   { FIELD("Version"),          f_version,         w_version,        PKGIFPOFF(version)       },
-  { FIELD("Revision"),         f_revision,        w_null                                     },
   { FIELD("Config-Version"),   f_configversion,   w_configversion                            },
   { FIELD("Replaces"),         f_dependency,      w_dependency,     dep_replaces             },
   { FIELD("Provides"),         f_dependency,      w_dependency,     dep_provides             },
@@ -84,17 +83,13 @@ const struct fieldinfo fieldinfos[]= {
   { FIELD("Triggers-Pending"), f_trigpend,        w_trigpend                                 },
   { FIELD("Triggers-Awaited"), f_trigaw,          w_trigaw                                   },
   /* Note that aliases are added to the nicknames table. */
-  {  NULL                                                                             }
-};
-
-static const struct nickname nicknames[] = {
-  /* Note: Capitalization of these strings is important. */
-  { NICK("Recommended"),      .canon = "Recommends" },
-  { NICK("Optional"),         .canon = "Suggests" },
-  { NICK("Class"),            .canon = "Priority" },
-  { NICK("Package-Revision"), .canon = "Revision" },
-  { NICK("Package_Revision"), .canon = "Revision" },
-  { .nick = NULL }
+  { FIELD("Revision"),         f_revision,        w_null                                     },
+  { FIELD("Recommended"),      f_dependency,      w_null                                     },
+  { FIELD("Optional"),         f_dependency,      w_null                                     },
+  { FIELD("Class"),            f_priority,        w_null                                     },
+  { FIELD("Package-Revision"), f_revision,        w_null                                     },
+  { FIELD("Package_Revision"), f_revision,        w_null                                     },
+  { NULL                                                                                     }
 };
 
 /**
@@ -116,19 +111,9 @@ pkg_parse_field(struct parsedb_state *ps, struct field_state *fs,
                 void *parse_obj)
 {
   struct pkg_parse_object *pkg_obj = parse_obj;
-  const struct nickname *nick;
   const struct fieldinfo *fip;
   int *ip;
 
-  for (nick = nicknames; nick->nick; nick++)
-    if (nick->nicklen == (size_t)fs->fieldlen &&
-        strncasecmp(nick->nick, fs->fieldstart, fs->fieldlen) == 0)
-      break;
-  if (nick->nick) {
-    fs->fieldstart = nick->canon;
-    fs->fieldlen = strlen(fs->fieldstart);
-  }
-
   for (fip = fieldinfos, ip = fs->fieldencountered; fip->name; fip++, ip++)
     if (fip->namelen == (size_t)fs->fieldlen &&
         strncasecmp(fip->name, fs->fieldstart, fs->fieldlen) == 0)
@@ -177,7 +162,7 @@ pkg_parse_verify(struct parsedb_state *ps,
   struct dependency *dep;
   struct deppossi *dop;
 
-  parse_must_have_field(ps, pkg->set->name, "package name");
+  parse_must_have_field(ps, pkg->set->name, "Package");
 
   /* XXX: We need to check for status != PKG_STAT_HALFINSTALLED as while
    * unpacking an unselected package, it will not have yet all data in
@@ -186,9 +171,9 @@ pkg_parse_verify(struct parsedb_state *ps,
   if ((ps->flags & pdb_recordavailable) ||
       (pkg->status != PKG_STAT_NOTINSTALLED &&
        pkg->status != PKG_STAT_HALFINSTALLED)) {
-    parse_ensure_have_field(ps, &pkgbin->description, "description");
-    parse_ensure_have_field(ps, &pkgbin->maintainer, "maintainer");
-    parse_must_have_field(ps, pkgbin->version.version, "version");
+    parse_ensure_have_field(ps, &pkgbin->description, "Description");
+    parse_ensure_have_field(ps, &pkgbin->maintainer, "Maintainer");
+    parse_must_have_field(ps, pkgbin->version.version, "Version");
   }
 
   /* XXX: Versions before dpkg 1.10.19 did not preserve the Architecture
@@ -200,9 +185,9 @@ pkg_parse_verify(struct parsedb_state *ps,
      * is in such a state that it make sense), so that it can be used safely
      * on string comparisons and the like. */
     if (pkgbin->arch->type == DPKG_ARCH_NONE)
-      parse_warn(ps, _("missing %s"), "architecture");
+      parse_warn(ps, _("missing '%s' field"), "Architecture");
     else if (pkgbin->arch->type == DPKG_ARCH_EMPTY)
-      parse_warn(ps, _("empty value for %s"), "architecture");
+      parse_warn(ps, _("empty value for '%s' field"), "Architecture");
   }
   /* Mark missing architectures as empty, to distinguish these from
    * unused slots in the db. */
@@ -211,12 +196,12 @@ pkg_parse_verify(struct parsedb_state *ps,
 
   if (pkgbin->arch->type == DPKG_ARCH_EMPTY &&
       pkgbin->multiarch == PKG_MULTIARCH_SAME)
-    parse_error(ps, _("package has field '%s' but is missing architecture"),
+    parse_error(ps, _("package has '%s' field but is missing architecture"),
                 "Multi-Arch: same");
   if (pkgbin->arch->type == DPKG_ARCH_ALL &&
       pkgbin->multiarch == PKG_MULTIARCH_SAME)
-    parse_error(ps, _("package has field '%s' but is architecture all"),
-                "Multi-Arch: same");
+    parse_error(ps, _("package has '%s' field but is architecture '%s'"),
+                "Multi-Arch: same", "all");
 
   /* Generate the cached fully qualified package name representation. */
   pkgbin->pkgname_archqual = pkgbin_name_archqual(pkg, pkgbin);
@@ -241,7 +226,8 @@ pkg_parse_verify(struct parsedb_state *ps,
           pkg->status == PKG_STAT_NOTINSTALLED ||
           pkg->status == PKG_STAT_TRIGGERSPENDING)
         parse_error(ps,
-                    _("Config-Version for package with inappropriate Status"));
+                    _("'%s' field present for package with inappropriate '%s' field"),
+                    "Config-Version", "Status");
     } else {
       if (pkg->status == PKG_STAT_INSTALLED ||
           pkg->status == PKG_STAT_TRIGGERSPENDING)
@@ -257,7 +243,8 @@ pkg_parse_verify(struct parsedb_state *ps,
                 pkg_status_name(pkg));
   else if (pkg->status == PKG_STAT_TRIGGERSAWAITED && !pkg->trigaw.head)
     parse_error(ps,
-                _("package has status triggers-awaited but no triggers awaited"));
+                _("package has status %s but no triggers awaited"),
+                pkg_status_name(pkg));
 
   if (pkg->trigpend_head &&
       !(pkg->status == PKG_STAT_TRIGGERSPENDING ||
@@ -267,8 +254,8 @@ pkg_parse_verify(struct parsedb_state *ps,
                 pkg_status_name(pkg));
   else if (pkg->status == PKG_STAT_TRIGGERSPENDING && !pkg->trigpend_head)
     parse_error(ps,
-                _("package has status triggers-pending but no triggers "
-                  "pending"));
+                _("package has status %s but no triggers pending"),
+                pkg_status_name(pkg));
 
   /* FIXME: There was a bug that could make a not-installed package have
    * conffiles, so we check for them here and remove them (rather than
@@ -277,8 +264,8 @@ pkg_parse_verify(struct parsedb_state *ps,
       pkg->status == PKG_STAT_NOTINSTALLED &&
       pkgbin->conffiles) {
     parse_warn(ps,
-               _("Package which in state not-installed has conffiles, "
-                 "forgetting them"));
+               _("package has status %s and has conffiles, forgetting them"),
+               pkg_status_name(pkg));
     pkgbin->conffiles = NULL;
   }
 
@@ -304,7 +291,18 @@ pkg_parse_verify(struct parsedb_state *ps,
       pkg->eflag == PKG_EFLAG_OK &&
       pkg->want == PKG_WANT_INSTALL &&
       pkgbin->arch->type == DPKG_ARCH_EMPTY)
-    pkg->want = PKG_WANT_UNKNOWN;
+    pkg_set_want(pkg, PKG_WANT_UNKNOWN);
+
+  /* XXX: Versions before dpkg 1.13.10 did not blank the Origin and Bugs
+   * fields, so there can be packages that should be garbage collected but
+   * are lingering around. Blank them to make sure we will forget all about
+   * them on the next database dump. */
+  if (!(ps->flags & pdb_recordavailable) &&
+      pkg->status == PKG_STAT_NOTINSTALLED &&
+      pkg->eflag == PKG_EFLAG_OK &&
+      pkg->want == PKG_WANT_UNKNOWN) {
+    pkgbin_blank(pkgbin);
+  }
 }
 
 struct pkgcount {
@@ -419,11 +417,12 @@ parse_find_pkg_slot(struct parsedb_state *ps,
     /* Verify we don't allow something that will mess up the db. */
     if (pkgset_installed_instances(db_set) > 1 &&
         !selection && new_pkgbin->multiarch != PKG_MULTIARCH_SAME)
-      ohshit(_("%s %s (Multi-Arch: %s) is not co-installable with "
-               "%s which has multiple installed instances"),
+      ohshit(_("package %s (%s) with field '%s: %s' is not co-installable "
+               "with %s which has multiple installed instances"),
              pkgbin_name(new_pkg, new_pkgbin, pnaw_always),
              versiondescribe(&new_pkgbin->version, vdew_nonambig),
-             multiarchinfos[new_pkgbin->multiarch].name, db_set->name);
+             "Multi-Arch", multiarchinfos[new_pkgbin->multiarch].name,
+             db_set->name);
 
     /* If we are parsing the status file, use a slot per arch. */
     if (ps->type == pdb_file_status)
@@ -526,6 +525,7 @@ parsedb_new(const char *filename, int fd, enum parsedbflags flags)
   struct parsedb_state *ps;
 
   ps = m_malloc(sizeof(*ps));
+  ps->err = DPKG_ERROR_OBJECT;
   ps->filename = filename;
   ps->type = parse_get_type(ps, flags);
   ps->flags = flags;
